@@ -94,6 +94,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
         ?>
       </ul>
     </div>
+    <?php if(common::canModify('product', $product)):?>
     <?php if(!common::checkNotCN()):?>
     <?php if(common::hasPriv('story', 'batchCreate')) echo html::a($this->createLink('story', 'batchCreate', "productID=$productID&branch=$branch&moduleID=$moduleID"), "<i class='icon icon-plus'></i> {$lang->story->batchCreate}", '', "class='btn btn btn-secondary'");?>
     <?php
@@ -141,6 +142,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
       </ul>
     </div>
     <?php endif;?>
+    <?php endif;?>
   </div>
 </div>
 <div id="mainContent" class="main-row fade">
@@ -167,7 +169,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
     <div class="table-empty-tip">
       <p>
         <span class="text-muted"><?php echo $lang->story->noStory;?></span>
-        <?php if(common::hasPriv('story', 'create')):?>
+        <?php if(common::canModify('product', $product) and common::hasPriv('story', 'create')):?>
         <?php echo html::a($this->createLink('story', 'create', "productID={$productID}&branch={$branch}&moduleID={$moduleID}"), "<i class='icon icon-plus'></i> " . $lang->story->create, '', "class='btn btn-info'");?>
         <?php endif;?>
       </p>
@@ -186,6 +188,18 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
       $setting = $this->datatable->getSetting('product');
       $widths  = $this->datatable->setFixedFieldWidth($setting);
       $columns = 0;
+
+      $canBeChanged         = common::canModify('product', $product);
+      $canBatchEdit         = ($canBeChanged and common::hasPriv('story', 'batchEdit'));
+      $canBatchClose        = (common::hasPriv('story', 'batchClose') and strtolower($browseType) != 'closedbyme' and strtolower($browseType) != 'closedstory');
+      $canBatchReview       = ($canBeChanged and common::hasPriv('story', 'batchReview'));
+      $canBatchChangeStage  = ($canBeChanged and common::hasPriv('story', 'batchChangeStage'));
+      $canBatchChangeBranch = ($canBeChanged and common::hasPriv('story', 'batchChangeBranch'));
+      $canBatchChangeModule = ($canBeChanged and common::hasPriv('story', 'batchChangeModule'));
+      $canBatchChangePlan   = ($canBeChanged and common::hasPriv('story', 'batchChangePlan'));
+      $canBatchAssignTo     = ($canBeChanged and common::hasPriv('story', 'batchAssignTo'));
+
+      $canBatchAction       = ($canBatchEdit or $canBatchClose or $canBatchReview or $canBatchChangeStage or $canBatchChangeModule or $canBatchChangePlan or $canBatchAssignTo);
       ?>
       <?php if(!$useDatatable) echo '<div class="table-responsive">';?>
       <table class='table has-sort-head<?php if($useDatatable) echo ' datatable';?>' id='storyList' data-fixed-left-width='<?php echo $widths['leftWidth']?>' data-fixed-right-width='<?php echo $widths['rightWidth']?>'>
@@ -196,7 +210,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
           {
               if($value->show)
               {
-                  $this->datatable->printHead($value, $orderBy, $vars);
+                  $this->datatable->printHead($value, $orderBy, $vars, $canBatchAction);
                   $columns ++;
               }
           }
@@ -224,11 +238,12 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
       </table>
       <?php if(!$useDatatable) echo '</div>';?>
       <div class="table-footer">
+        <?php if($canBatchAction):?>
         <div class="checkbox-primary check-all"><label><?php echo $lang->selectAll?></label></div>
+        <?php endif;?>
         <div class="table-actions btn-toolbar">
           <div class='btn-group dropup'>
             <?php
-            $canBatchEdit  = common::hasPriv('story', 'batchEdit');
             $disabled   = $canBatchEdit ? '' : "disabled='disabled'";
             $actionLink = $this->createLink('story', 'batchEdit', "productID=$productID&projectID=0&branch=$branch");
             ?>
@@ -236,13 +251,12 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
             <button type='button' class='btn dropdown-toggle' data-toggle='dropdown'><span class='caret'></span></button>
             <ul class='dropdown-menu'>
               <?php
-              $canBatchClose = common::hasPriv('story', 'batchClose') && strtolower($browseType) != 'closedbyme' && strtolower($browseType) != 'closedstory';
               $class         = $canBatchClose ? '' : "class='disabled'";
               $actionLink    = $this->createLink('story', 'batchClose', "productID=$productID&projectID=0");
               $misc = $canBatchClose ? "onclick=\"setFormAction('$actionLink')\"" : '';
               echo "<li $class>" . html::a('#', $lang->close, '', $misc) . "</li>";
 
-              if(common::hasPriv('story', 'batchReview'))
+              if($canBatchReview)
               {
                   echo "<li class='dropdown-submenu'>";
                   echo html::a('javascript:;', $lang->story->review, '', "id='reviewItem'");
@@ -283,7 +297,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
                   echo "<li $class>" . html::a('javascript:;', $lang->story->review,  '', $class) . '</li>';
               }
 
-              if(common::hasPriv('story', 'batchChangeBranch') and $this->session->currentProductType != 'normal')
+              if($canBatchChangeBranch and $this->session->currentProductType != 'normal')
               {
                   $withSearch = count($branches) > 8;
                   echo "<li class='dropdown-submenu'>";
@@ -300,7 +314,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
                   echo '</div></li>';
               }
 
-              if(common::hasPriv('story', 'batchChangeStage'))
+              if($canBatchChangeStage)
               {
                   echo "<li class='dropdown-submenu'>";
                   echo html::a('javascript:;', $lang->story->stageAB, '', "id='stageItem'");
@@ -323,7 +337,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
             </ul>
           </div>
 
-          <?php if(common::hasPriv('story', 'batchChangeModule')):?>
+          <?php if($canBatchChangeModule):?>
           <div class="btn-group dropup">
             <button data-toggle="dropdown" type="button" class="btn"><?php echo $lang->story->moduleAB;?> <span class="caret"></span></button>
             <?php $withSearch = count($modules) > 8;?>
@@ -350,7 +364,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
             </div>
           </div>
           <?php endif;?>
-          <?php if(common::hasPriv('story', 'batchChangePlan')):?>
+          <?php if($canBatchChangePlan):?>
           <div class="btn-group dropup">
             <button data-toggle="dropdown" type="button" class="btn"><?php echo $lang->story->planAB;?> <span class="caret"></span></button>
             <?php
@@ -381,7 +395,7 @@ js::set('foldAll',       $lang->project->treeLevel['root']);
           </div>
           <?php endif;?>
 
-          <?php if(common::hasPriv('story', 'batchAssignTo')):?>
+          <?php if($canBatchAssignTo):?>
           <div class="btn-group dropup">
             <button data-toggle="dropdown" type="button" class="btn"><?php echo $lang->story->assignedTo;?> <span class="caret"></span></button>
             <?php
@@ -431,8 +445,8 @@ $(function()
     $storyCommon = $lang->storyCommon;
     if(!empty($config->URAndSR))
     {
-        if($storyType == 'requirement') $storyCommon = $lang->urCommon;
-        if($storyType == 'story') $storyCommon = $lang->srCommon;
+        if($storyType == 'requirement') $storyCommon = $lang->URCommon;
+        if($storyType == 'story') $storyCommon = $lang->SRCommon;
     }
     ?>
     var checkedSummary = '<?php echo str_replace('%storyCommon%', $storyCommon, $lang->product->checkedSummary)?>';
